@@ -6,15 +6,18 @@ test_that("sar_power returns correct results", {
   expect_equal(round(fit$AICc, 2), 189.03)
   expect_equal(as.vector(round(fit$par[2], 2)), 0.28)
   expect_is(fit, "sars")
-  expect_match(fit$normaTest[[1]], "lillie")
+  expect_match(fit$normaTest[[1]], "none")
   expect_error(sar_linear(5), "data must be a matrix or dataframe")
+  fit2 <- sar_power(galap, homoTest = "cor.fitted")
+  expect_equal(as.vector(round(fit2$homoTest[[2]]$p.value, 2)), 0.04)
+  expect_match(fit2$homoTest[[2]]$method, "Spearman's rank correlation rho")
 })
 
 
 #changed neg_expo function allowing z to be > 1, and also the change to 
 #asymp setting z to Rplus rather than R
 test_that("neg_expo and asymp returns correct results", {
-  fit <- sar_negexpo(niering)
+  fit <- sar_negexpo(niering, grid_start = "none")
   expect_equal(round(fit$AICc, 2), 207.39)
   expect_equal(as.vector(round(fit$par[2], 2)), 26.14)
   fit2 <- sar_asymp(niering)
@@ -24,9 +27,9 @@ test_that("neg_expo and asymp returns correct results", {
 
 
 test_that("sar_power summary returns correct results", {
-  fit <- sar_power(galap)
+  fit <- sar_power(galap, normaTest = "lillie")
   fs <- summary(fit)
-  expect_equal(sum(fs$residuals), 31.4)
+  expect_equal(round(sum(fs$residuals), 0), -31)#grid start so round to 0
   expect_output(str(fs), "List of 16")
   expect_is(fs, "summary.sars")
   expect_equal(round(fs$normaTest[[2]]$p.value, 3), 0.056)
